<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>SRC Eklentisi</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Örnekleme Oranı Dönüştürücü Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Qmmp Örnekleme Oranı Dönüştürücü Eklentisi</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SRConverterSettingsDialog</name>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Örnekleme Oranı Dönüştürücü Eklentisi Ayarları</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Örnekleme Oranı (Hz):</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="40"/>
        <source>Interpolation Engine:</source>
        <translation>İnterpolasyon Motoru:</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="48"/>
        <source>Best Sinc Interpolation</source>
        <translation>Best Sinc İnterpolasyonu</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="53"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Medium Sinc İnterpolasyonu</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="58"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Fastest Sinc İnterpolasyonu</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="63"/>
        <source>ZOH Interpolation</source>
        <translation>ZOH İnterpolasyonu</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="68"/>
        <source>Linear Interpolation</source>
        <translation>Doğrusal İnterpolasyon</translation>
    </message>
</context>
</TS>
